Monty Python's Flying Circus: Just the Words - Episode 28

# Episode Twenty-eight

Emigration from Surbiton to Hounslow
Schoolboys' Life Assurance Company
How to rid the world of all known diseases
Mrs Niggerbaiter explodes
Vicar/salesman
Farming club
'Life of Tschaikowsky'
Trim-Jeans Theatre
Fish-slapping dance
World War One
The BBC is short of money
Puss in Boots

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

Voice Over | and CAPTIONS: 'THE KON-TIKI' 'RA 1' 'RA 2' 'AND NOW ...' 'MR AND MRS BRIAN NORRIS' FORD POPULAR'
| Pull back from a shot of an old little Ford Popular to reveal Mr and Mrs Norris, standing with it outside the front garden of a small suburban semi-detached house.
Voice Over | Who, a year ago, had heard of Mr and Mrs Brian Norris of 37, Gledhill Gardens, Parsons Green? And yet their epic journey in EBW 343 has set them alongside Thor Heyerdahl and Sir Edmund Hillary. Starting only with a theory, Mr Norris set out to prove that the inhabitants of Hounslow could have been descendants of the people of Surbiton who had made the great trek north. No newcomer to this field, Mr Norris's 'A Short History of Motor Traffic Between Purley and Esher' had become a best-selling minor classic in the car-swapping belt. (shot of Mr Norris gazing into a window, where his book lies; there is a sign saying 'Remaindered') But why would the people of Surbiton go to Hounslow? Mr Norris had noticed three things: (split-screen shot of two identical semi-detached houses) Firstly, the similarity of the houses. Secondly, the similarity of the costume between Hounslow and Surbiton, (similarly, dressed suburbanites on other side of the split screen) and thirdly, the similarity of speech.
| Split screen.
Man on Right | Are you still running the GDBDMDB?
Man on Left | Yes, but I've had the excess nipples woppled to remove tamping.
Man on Right | Jolly good.
Voice Over | Were these just coincidences, or were they, as Mr Norris believed, part of an identical cultural background? One further discovery convinced him. (cut to two lawnmowers arranged on a table, as if they were exhibits in a museum, with type-written documentation in front of them for the visitor) The lawnmower. Surely such a sophisticated household gadget could not have been generated independently in two separate areas. Mr Norris was convinced.
Mr Norris's Voice | I'm convinced.
Voice Over | But how to prove it.
Mr Norris's Voice | But how to prove it.
Voice Over | There was only one way to see if the journey between Surbiton and Hounslow was possible, and that was to try and make it. Months of preparation followed whilst Mr Norris continued his research in the Putney Public Library, (Mr Norris in a library reading a book titled 'The Lady with the Naked Skin' by Paul Fox Jnr) and Mrs Norris made sandwiches.
| Cut to Mr and Mrs Norris leaving their home.
Voice Over | Finally, by April, they were ready. On the 23rd, Mr and Mrs Norris set out from 'Abide-A-Wee' to motor the fifteen miles to Surbiton, watched by a crowd of local well-wishers. (one tiny child holding a small British flag) That evening they dined at Tooting. (quick flash of them sitting in the window of a Golden Egg or Wimpy place) This would be the last they'd see of civilization. Mr Norris's diary for the 23rd reveals the extraordinary calmness and deep inner peacefulness of his mind.
| We see the diary.
Mr Norris's Voice | 7.30 Fed cat. 8.00 Breakfast. 8.30 Yes (successfully). 9.00 Set out on historic journey.
| Cut to Mr Norris's car driving along a suburban road. A sign says 'You are now leaving Surbiton, gateway to Esher'.
Voice Over | On the morning of the 24th, early to avoid the traffic, Mr Norris's historic expedition set out from Surbiton - destination Hounslow. Early on they began to perceive encouraging signs. (cut to sign saying 'Hounslow 25 miles'; Mr Norris closely examines the sign, as would an archaeologist) The writing on the sign was almost exactly the same as the writing in the AA book. They were on the right route. During the long hours of the voyage, Mr Norris's wife Betty kept a complete photographic record and made sandwiches. This is some of the unique footage which Mrs Norris got back from the chemists... (badly shot pictures of sandwiches, with fingers in the lens, etc.) Mile succeeded mile and the terrific strain was beginning to tell when suddenly, (chord; Mr Norris points excitedly, pull back to reveal him standing on a bridge over the Kingston by-pass examining it through field glasses) by an amazing stroke of luck, Mr Norris had come across the Kingston by-pass. This was something to tell the Round Table. (cut to a map, it traces the two routes in red as the voice talks) At this stage, Mr Norris was faced with two major divergent theories concerning his Surbiton ancestors. Did they take the Kingston by-pass, turning left at Barnes, or did they strike west up the A308 via Norbiton to Hampton Wick? Both these theories ran up against one big obstacle - the Thames, (the car at a river bank; Mr and Mrs Norris puzzling; behind them three or four bridges with traffic pouring over) lying like a silver turd between Richmond and Isleworth. This was a major setback. How could they possibly cross the river? Several hours of thought produced nothing. There was only one flask of coffee left when suddenly Mr Norris spotted something. (cut to a sign saying Metropolitan Railway) Could this have been the method used? Hardly daring to believe, Mr Norris led his expedition on to the 3.47. (cut to them getting on the train) Forty minutes later, via Clapham, Fulham, Chiswick and Brentford, they approached their goal: Hounslow. (a sign saying 'Hounslow Central'; Mr Norris sticks a British flag on the platform; he poses for his wife's photos; much hand shaking) Was this, then, the final proof? Something aroused the accountant's instinct buried deep in Mr Norris's make-up. (cut to Mr Norris's eyes and furrowed brow) The journey was possible, and yet .... (zoom in on railway timetable on wall saying 'Trains to Surbiton every half hour') 'Wrong Way' Norris had accidentally stumbled on a piece of anthropological history. It was the inhabitants of Hounslow who had made the great trek south to the sunnier pastures of Surbiton, and not vice versa, as he had originally surmised. This was the secret of Surbiton! Happy and contented Mr Norris returned to the calmer waters of chartered accountancy, for, in his way, 'Wrong Way' Norris was right.
| Music swells, over book title 'The Story of EBW 343 ' by 'Wrong Way' Norris.
| CAPTION: 'THE END'
| A music crescendo. Cut to nude organist (Terry J) playing a chord.
Announcer | And now...
It's Man | It's...
| Animated titles.
Voice | Monty Python's Flying Circus.
| Cut to a headmaster's study.
Headmaster | Knock, enter and approach. (knock on door; it opens and three schoolboys in short trousers enter) Right, it's come to my notice that certain boys have been running a unit-trust linked assurance scheme with fringe benefits and full cash-in endowment facilities. Apparently small investors were attracted by the wide-ranging portfolio and that in the first week the limited offer was oversubscribed eight times.
Stebbins | It was Tidwell's idea, sir.
Headmaster | Shut up, Stebbins! I haven't finished. Oh, by the way, congratulations on winning the Italian Grand Prix at Monza.
Stebbins | Thank you, sir.
Headmaster | Shut up. Now then, this sort of extra-curricular capitalist expansion has got to stop. I made it quite clear when Potter tried to go public last term, that these massive stock exchange deals must not happen in Big School. Is that clear, Balderston?
Balderston | Yes, sir.
Headmaster | Oh, and Balderston, next time you do a 'Panorama' Report on the Black Ghettos you must get an exeat form from Mr Dibley.
Balderston | Sorry, sir.
Headmaster | Shut up, and stop slouching. Now, the reason I called you in here today, is that my wife is having a little trouble with her,.. er... with her waterworks, and I think she needs a bit of attention. Now, which one of you is the surgeon? (silence) Come on, I know one of you is, which one is it? (Tidwell raises hand reluctantly) Ah! Tidwell. Good. Well, I want you to come along and have a look at the wife.
Tidwell | Oh, sir! Why don't you ask Stebbins? He's a gynaecologist.
Stebbins | Ooh! You rotten stinker, Tidwell!
Headmaster | Is this true, Stebbins? Are you a gynaecologist?
Stebbins | (very reluctantly) Yes, sir.
Headmaster | Right, just the man. How much do you charge?
Stebbins | (muttering into his shoes) Thirty guineas, sir.
Headmaster | Excellent. Right. I want you to go along to see the wife. Give her a full examination, and let me know the results by the end of break. And don't pick your nose!
| Cut to a sign saying 'How to do it'. Music. Pull out to reveal a 'Blue Peter' type set. Sitting casually on the edge of a dais are three presenters in sweaters - Noel, Jackie and Alan - plus a large bloodhound.
Alan | Hello.
Noel | Hello.
Alan | Well, last week we showed you how to become a gynaecologist. And this week on 'How to do it' we're going to show you how to play the flute, how to split an atom, how to construct a box girder bridge, how to irrigate the Sahara Desert and make vast new areas of land cultivatable, but first, here's Jackie to tell you all how to rid the world of all known diseases.
Jackie | Hello, Alan.
Alan | Hello, Jackie.
Jackie | Well, first of all become a doctor and discover a marvellous cure for something, and then, when the medical profession really starts to take notice of you, you can jolly well tell them what to do and make sure they get everything right so there'll never be any diseases ever again.
Alan | Thanks, Jackie. Great idea. How to play the flute. (picking up a flute) Well here we are. You blow there and you move your fingers up and down here.
Noel | Great, great, Alan. Well, next week we'll be showing you how black and white people can live together in peace and harmony, and Alan will be over in Moscow showing us how to reconcile the Russians and the Chinese. So, until next week, cheerio.
Alan | Bye.
Jackie | Bye.
| Children's music. Pull out to reveal that the 'Blue Peter' set is in one corner of a stockbroker-belt sitting room. Two ladies are sitting by the fire looking at a photo album.
Mrs Nigger-Baiter | Oh, yes, he's such a clever little boy, just like his father.
Mrs S | D'you think so, Mrs Nigger-Baiter?
Mrs Nigger-Baiter | Oh yes, spitting image.
| The door opens. The son comes in.
Son | Good afternoon, mother. Good afternoon, Mrs Nigger-Baiter.
Mrs Nigger-Baiter | Ooh, he's walking already!
Mrs S | Yes, he's such a clever little boy, aren't you? Coochy coochy coo . . .
Mrs Nigger-Baiter | Hello, coochy coo...
Mrs S | Hello, hello... (they chuck him under the chin)
Mrs Nigger-Baiter | Oochy coochy. (the son smiles a little tight smile) Look at him laughing... ooh, he's a chirpy little fellow. Isn't he a chirpy little fellow ... eh? eh? Does he talk Does he talk, eh?
Son | Of course I talk, I'm Minister for Overseas Development.
Mrs Nigger-Baiter | Ooh, he's a clever little boy - he's a clever little boy. (gets out a rattle) Do you like your rattle? Do you like your rattle? Look at his little eyes following it ... look at his iggy piggy piggy little eyeballs eh... oo... he's got a tubby tum-tum. Oh, he's got a tubby tum-tum.
Son | (whilst Mrs Nigger-Baiter is talking) Mother, could I have a quick cup of tea please. I have an important statement on Rhodesia to make in the Commons at six.
| Sound of an explosion out of vision. Cut to reveal Mrs Nigger-Baiter's chair charred and smoking. Mrs Nigger-Baiter is no longer there. The upholstery is smouldering gently.
Mrs S | Oh, Mrs Nigger-Baiter's exploded.
Son | Good thing, too.
Mrs S | She was my best friend.
Son | Oh, mother, don't be so sentimental. Things explode every day.
Mrs S | Yes, I suppose so. Anyway, I didn't really like her that much.
| The doorbell rings. Mrs S goes to the door. A vicar with a suitcase.
Vicar | Hello, I'm your new vicar. Can I interest you in any encyclopaedias?
Mrs S | Ah, no thank you. We're not Church people, thank you.
| The vicar opens his suitcase to reveal it is packed with brushes.
Vicar | How about brushes? Nylon or bristle? Strong-tufted, attractive colours.
Mrs S | No - really, thank you, vicar.
Vicar | Oh dear ... Turkey? Cup final tickets?
Mrs S | No, no really, we're just not religious thank you.
Vicar | Oh, well. Bye bye.
Mrs S | Bye bye, vicar. (she shuts the door, as she returns to seat the vicar pops his head round the door again)
Vicar | Remember, if you do want anything... jewellery, Ascot water heaters...
Mrs S | Thank you, vicar. (he goes) It's funny, isn't it? How your best friend can just blow up like that? I mean, you wouldn't think it was medically possible, would you?
| Cut to a doctor in a posh consulting room.
Doctor | This is where Mrs Shazam was so wrong. Exploding is a perfectly normal medical phenomenon. In many fields of medicine nowadays, a dose of dynamite can do a world of good. For instance, athlete's foot - an irritating condition - can be cured by applying a small charge of TNT between each toe. (doorbell) Excuse me. (he opens the door)
Vicar | Hello, I'm your new vicar, can I interest you in any of these watches, pens or biros? (exhibits the collection inside his jacket)
Doctor | No ... I'm not religious, I'm afraid.
Vicar | Oh, souvenirs, badges... a little noddy dog for the back of the car?
Doctor | No thank you, vicar. Good morning.
Vicar | Oh, morning.
| He shuts the door.
Doctor | Now, many of the medical profession are sceptical about my work. They point to my record of treatment of athlete's foot sufferers - eighty-four dead, sixty-five severely wounded and twelve missing believed cured. But then, people laughed at Bob Hope, people laughed at my wife when she wrapped herself up in greaseproof paper and hopped into the Social Security office, but that doesn't mean that Pasteur was wrong! Look, I'll show you what I mean. (goes to a wall diagram of two skeletons and taps one with a rod)
| ANIMATION:
Skeleton | Watch it, mate. I'm not going to stay round here getting poked and prodded all day. (clips a face on and moves off the diagram) I'm off... I've got a decent body, all I get is poked and prodded in the chest. (moving through countryside) Well, I'm off. I'm going to get another line of work. (goes past various warning signs)
Voice | Watch it!
Voice | Don't go any further!
Voice | Turn back!
Voice | Stop!
| The sprocket holes at the side of the film come into view.
Voice | Stop! Oh, please stop!
| The skeleton moves past the sprocket holes and falls into blank space.
Voice | Oh, my god, he's fallen off the edge of the cartoon.
Voice | Well, so much for that link.
| Artistic-type set. There is a large screen on back. Stock two-chair set-up as for interview.
Presenter | John Cobbley is the Musical and Artistic Director of Covent Garden. He is himself a talented musician, he is a world famous authority on nineteenth-century Russian music and he's come into the studio tonight to talk about Tschaikowsky, which is a bit of a pity as this is 'Farming Club'. On 'Farming Club' tonight we'll be taking a look at the Ministry's (pigs appear on the screen, Cobbley gets up, looks about him, wanders off, rather puzzled) latest preventative proposals to deal with a possible outbreaks of foot and mouth, we'll be talking later to the man who believes that milk yields can be increased dramatically, but first a Farming Club special, the life of Tschaikowsky.
| Cue Tschaikowsky's first piano concerto. Stock film of a farmyard with superimposed roller caption.
| ROLLER CAPTION: 'FARMING CLUB, IN ASSOCIATION WITH THE POTATO MARKETING BOARD, ALSO IN ASSOCIATION WITH THE BEETROOT, HAM, EGG AND TOMATO MARKETING BOARD, AND ALSO IN ASSOCIATION WITH THE LITTLE GREEN BITS OF CUCUMBER DICED WITH SHALLOTS, GARNISHED WITH CHIVES AND SERVED WITH A ROQUEFORT DRESSING MAKES AN EXCELLENT APPETIZER OR SIDE DISH WITH A STEAK OR A STEW MARKETING BOARD, PRESENTS: THE LIFE OF PETER ILYICH TSCHAIKOWSKY, IN ASSOCIATION WITH THE PETER ILYICH TSCHAIKOWSKY MARKETING BOARD'
| Cut back to the presenter.
Presenter | Tschaikowsky. Was he the tortured soul who poured out his immortal longings into dignified passages of stately music, or was he just an old poof who wrote tunes? (pull back to show a second presenter in the other chair) Tonight on 'Farming Club' we're going to take an intimate look at Tschaikowsky (a picture of Tschaikowsky on the screen) and an intimate look at his friends. (a picture of a naked sailor on a tiger-skin rug) Incidentally, BBC Publications have prepared a special pamphlet to go with this programme called 'Hello Pianist', (It comes up on the screen; on its cover there is a picture of a pig) and it contains material that some people might find offensive but which is really smashing.
Second Presenter | Peter Ilyich Tschaikowsky was born in 1840 in a Ken Russell film just outside St Petersburg. His father (Leo McKern), a free-lance bishop, was married to Verna Plachenka (Julie Christie) but secretly deeply in love with Margo Farenka (Shirley Abicair) and the strangely flatulent Madame Ranevsky (Norris McWhirter). Soon, however, the family (Eldridge Cleaver, Moira Lister and Stan the Bat) moved to the neighbouring industrial village of Omsk (Eddie Waring) where they soon found themselves, sadly, quite unable to cope (Anthony Barber). In 1863, however, Tschaikowsky was sent to Moscow to study the piano and, when he'd finished that, the living room. Maurice takes up the story.
| Cut to a poofy presenter in really chintzy surroundings.
Maurice | Well, guess what, the very next thing he did was to go to this extraordinary but extraordinary duckety-poos semi-Mondrian house in Robin Russia. Harry here Tammy Tschaikowsky wrote some of the most Sammy super symphonies you've ever Henry heard in the whole of your Lily life.
| SUPERIMPOSED CAPTION: 'A FAMOUS MUSIC CRITIC AND HAIRDRESSER'
Maurice | She was such a good composer that everybody, but everybody, wanted to know, and quite right too, because she wrote some lovely bits, such as Sally Sleeping Beauty, Patsy Pathétique, Adrian 1812 and lots of Conny concerti for Vera violin and Peter Piano Fanny Forte.
| Cut back to second presenter.
Second Presenter | But what do we really know of this tortured ponce?
| Cut to space-programme-type set. Experts at a desk. An Apollo-type monograph behind them says 'Tchaikowsky XII'. The centre motif is a picture of Tschaikowsky.
Expert | Well, if you can imagine the size of Nelson's Column, which is roughly three times the size of a London bus, then Tschaikowsky was much smaller. His head was about the same size as that of an extremely large dog, that is to say, two very small dogs, or four very large hamsters, or one medium-size rabbit if you count the whole of the body and not just the head. Robin.
| He has a model of Tschaikowsky which comes apart.
Second Expert | Thank you. Well here is a three-stage model of Tschaikowsky... here you see the legs, used for walking around, and which can be jettisoned at night ... (he takes the legs off) And this is the main trunk, the power house of the whole thing, incorporating of course the naughty bits, which were extremely naughty for his time, and the whole thing is subservient to (takes it off) this small command module, the, as it were, head of the whole, as it were, body. Robin.
| Cut to first expert.
First Expert | Peter.
| Cut to first presenter.
First Presenter | Simon.
| Cut to second presenter.
Second Presenter | Maurice.
| Cut to Maurice.
Maurice | Me. Well, poor pet, she was like a lost lamb in an abattoir. Eventually she Dickie died of Colin Cholera in St Patsy Petersburg, in Gertie great Percy pain.
| Cut to a piano in a pool of light.
Voice Over | Here to play Tchaikowsky's first piano concerto in B Flat Minor is the world-famous soloist Sviatoslav Richter. During the performance he will escape from a sack, three padlocks and a pair of handcuffs.
| A chained figure in a sack rolls into shot and starts rolling about and playing the piano concerto. After a minute 'Rita' enters and gestures to him. She is in fish-net tights, etc, - the full conjurer's assistant. He wriggles free from the sack, playing the while. The music stops.
| CAPTION: 'SVIATOSLAV RICHTER AND RITA'
| Film of an applauding audience in the Royal Albert Hall,
| SUPERIMPOSED CAPTION: 'AND NOW'
| Jolly showbiz music. A curtain goes up, revealing three actors in trim-jeans (which are heavily padded to make you sweat off weight) grouped à la advert. They all have slight Australian accents.
| CAPTION: 'TRIM-JEANS THEATRE PRESENTS'
Gary | Good evening. This new series of 'Trim-Jeans Theatre Presents' will enable you to enjoy the poetry of T. S. Eliot whilst losing unsightly tummy bulge. Jean.
| CAPTION: 'THESE THREE PEOPLE ARE REDUCING THEIR WAIST, THIGHS, HIPS AND ABDOMEN EVEN AS THEY RECOMMEND'
Jean | Wow, yes and the inches stay off. Mark.
Mark | Terrific! Thrill to Thomas a Becket's Kierkegaardian moment of choice while making your physique tighter, firmer, neater.
| Cut to a cathedral interior. There are three priests, four knights and two women, all in trim-jeans. Thomas does not wear one.
Priest | I am here. No traitor to the King.
First Knight | Absolve all those you have excommunicated.
Second Knight | Resign those powers you have arrogated.
Third Knight | Renew the obedience you have violated.
Fourth Knight | Lose inches off your hips, thighs, buttocks and abdomen.
| Cut back to Gary and the others.
Gary | A terrific product.
All | Terrific.
Gary | And this comes complete with the most revolutionary guarantee in slenderizing history!
| Cut to a man (Terry J) in trim-jeans under a sign saying 'Before'.
Voice Over | This was Kevin Francis before last season's 'Trim-Jean Play of the Month' production of 'The Seagull' by Anton Chekhov and the Sauna Belt Trim-Jean Company Limited. See Kevin has slipped into his slenderizing garment and is inflating it with the handy little pump provided. Three acts and a few special torso exercises later, Kevin, as Trigorin, the failed writer of sentimental romances, has lost over thirty-three inches. (same shot but very skinny John Hughman has replaced Terry J) Wow. What a difference. That Anton Chekhov can certainly write.
Gary | Terrific.
Mark | Terrific.
Gary | Yes, why not join us for a season of classic plays and rapid slenderizing. Enjoy Sir John Gielgud and Sir Ralph Richardson losing a total of fifteen inches in David Storey's 'Home'.
Mark | Enjoy the 'The Trim Gentlemen of Verona' and 'Long Day's Journey into Night' while inches melt away.
Jean | Enjoy Glenda Jackson with a Constant Snug Fit and Solid Support in all four areas.
Gary | Other productions will include... 'Treasure Island' ... (Long John Silver in trim-jeans) 'Swan Lake' (cut to a photo of two ballet dancers in a 'lift' position, both wearing tights and trim-jeans) 'The Life and Loves of Toulouse Lautrec', (cut to a photo of Toulouse Lautrec, his feet sticking out of the bottom of the trim-jeans) and the Trim-Jeans version of 'The Great Escape', with a cast of thousands losing well over fifteen hundred inches.
| Cut to scrubland, barbed wire a la prison camp in the background. After a few seconds a head appears out of a hole in the ground. He looks around then gets out. He is wearing trim-jeans. He looks back. Satisfied he beckons. Others start appearing. Three German guards behind the wire muttering.
| SUPERIMPOSED CAPTION: 'INCHES LOST SO FAR'
| A superimposed counter shows the numbers increasing.
Guard | Achtung! Halt! Halt!
| A moment's panic. Shooting starts and a siren goes. Men pour out of hole rapidly. Guards pursue them with tracker dogs in trim-jeans. The counter goes berserk.
| An animated item ends with a sign saying 'And now, the Fish Slapping Dance.' Cut to a quayside. John and Michael, dressed in tropical gear and solar topees. John stannds still while Michael dances up and down before him to the jolly music of Edward German. Michael holds up two tiny fish and from time to time in the course of the dance he slaps John lightly across the cheeks with them. The music ends; Michael stops dancing. John produces a great fish and swipes Michael with it. Michael falls off the quay into the water.
| ANIMATION: underwater. We see an animated Michael sinking. He is swallowed by a fish with a swastika on its side.
Nazi Fish | Welcome aboard, Britisher pig. Quite a little surprise, ja? But perhaps you would be so kind as to tell us all you know about certain allied shipping routes, ja? Come on, talk!
| The Nazi fish is swallowed by a fish with an RAF emblem.
British Fish | Hello, Fritz. Tables seem to have turned, old chap, let's see how you like a bit of your own medicine, eh? Come on, Fritz, now tell us - tell us about...
| The British fish is swallowed by a Chinese fish.
Chinese Fish | Ah, gleetings, capitalist dog; very sorry but must inform you, you are now prisoner of People's Republic.
Second Voice | Am very sorry, comrade commando, but we have just picked up capitalist ship on ladar scanner.
| The Chinese fish bites the underside of a large ship. Film of big liner sinking in storm. General panic and dramatic music.
Captain | (over tannoy) This is your captain speaking. There is no need for panic. Woman and children first. I repeat that, women and children first.
| Cut to the ship's bridge. The captain and two or three officers are seen scrambling into ladies clothing or young children's short trousers and school satchels and caps. The ship pitches and rolls in the gale. The captain is still trying to speak into the PA.
Captain | Do not rush for the lifeboats - remember, women and children first.
| A first officer is revealed in the corner of the bridge putting a head-dress on a Red Indian outfit.
First Officer | And Red Indians!
Captain | (putting his hand over the PA) What did you have to get dressed up like that for?
First Officer | It was the only thing left.
Captain | Oh. All right. (into the PA) Women, children and Red Indians...
| Cut to another officer in astronaut's kit.
Second Officer | And spacemen!
Captain | Here is a revised list. Women, children, Red Indians and spacemen, (hand over PA) what's that meant to be?
| Cut to third officer who is putting finishing touches to a medieval outfit.
Third Officer | Well it's a sort of impression of what a kind of Renaissance courtier artist might have looked like at the court of one of the great families like the Medicis or the Borgias...
Fourth Officer | No it's not, it's more Flemish than Italian.
Fifth Officer | Yes - that's a Flemish merchant of the fifteenth or sixteenth centuries...
Third Officer | What! With these tassles?
Fourth Officer | Yes, yes. They had those fined doublets going tapering down into the full hose you know - exactly like that.
Captain | (into the PA) One moment, please, don't panic. (puts his hand over the PA) Now, what is it meant to be? I've got to tell them something. .. is it a Flemish merchant?
Third Officer | No, it is not a Flemish merchant. It's more a sort of idealized version of the complete Renaissance Man...
Captain | Oh, all right.
Fourth Officer | It's not...
Captain | All right! All right! (into the PA) this is your captain speaking... do not rush for the lifeboats ... women, children, Red Indians, spacemen (stock film of long shot of sinking vessel, the voice over fading) and a sort of idealized version of complete Renaissance Men first!
| CAPTION: 'A FEW DAYS LATER'
| Cut to a police chief's office in an anonymous South American police state. The chief of police at his desk. From outside we hear footsteps approaching the office and voices.
Third Officer's Voice | Flemish merchants did not wear hand-embroidered chevrons. They did not!
| The door opens and two guards roughly push in the captain in drag, another officer half in drag, half in naval uniform, two officers hastily dressed as children, a complete Renaissance Man, a Red Indian and a spaceman. They stand there for a moment. Then one of the guards pushes his way forward and hands the police chief a piece of paper.
Police Chief | Yes, Gomez? (reads) Vee found zem valking on zee beach, my capitain. (the guard nods enthusiasticaly) Gomez, why can't you say this? (the guard mouths something) What? Oh, I see, we can't afford it. (to camera) You see the BBC has to pay an actor twenty guineas if he speaks and it makes a bit of a hole in the budget...
Guard | Twenty-eight guineas, sir! Ooh, sorry.
Police Chief | You fool Gomez - that's twenty-eight guineas ...
Second Guard | What about me, sir?
Police Chief | Are you supposed to speak?
Second Guard | No, sir.
Police Chief | But you've just spoken!
Second Guard | Oh, sorry, sir.
Police Chief | You fool, that's, that's fifty-six guineas before we've even started; (a third guard suddenly rushes up to the window and flashes through it; scream and breaking glass) What did he do that for?
Second Guard | It's a stunt, sir, an extra twenty guineas.
Police Chief | (banging the desk) Look! We can't afford it! The BBC are short of money as it is.
| Cut to a newsreader in a 'News at Nine' set with a bare light bulb hanging in shot. He wears only an old blanket around his shoulders. He is shivering.
Newsreader | The BBC wishes to deny rumours that it is going into liquidation. Mrs Kelly, who owns the flat where they live, has said that they can stay on till the end of the month ... (he is handed a piece of paper) and we've just heard that Huw Weldon's watch has been accepted by the London Electricity Board and transmissions for this evening can be continued as planned. (he coughs and pulls the blanket tighter round his shoulders) That's all from me so... goodnight.
| Knocking on the door.
Mr Kelly's Voice | Are you going to be in there all night?
Newsreader | It's just a bulletin, Mr Kelly... and now back to the Story (banging)... All right!
| Cut back to the same police chief's office. Noises off of people walking down. The door opens and the same crowd is pushed in. No one has any trouses on.
First Guard | ve found ze men, valking on ze beach, my capitain.
Captain | We're British Naval Officers, and entitled to be...
| Enter a pantomime principal boy holding a stuffed cat. All the rest of the group break back in a well-choreographed panto arrowhead and raise their hands toward her.
All | It's ... Puss!
Audience | Hello, Puss!
Principal Boy (Julia Breck) | Hello, children!
Police Chief | Stop! Stop this adaptation of 'Puss-in-Boots'! This is the Police Department of the State of Venezuela!
Principal Boy | Oh no it isn't!
Police Chief | Oh, yes it is!
Principal Boy | (kids joining in voice over) Oh no it isn't!
All | (plus kids) Oh yes it is!
Principal Boy | (plus kids) Oh no it isn't...
Police Chief | Shut up! Shut up! (getting up, holding a pistol; he has no trousers; silence) Now I'm going to ask you some questions, and remember, if you do not give me correct answers, we have ways of making you answer!
Voice From Back | Like not paying twenty-eight guineas.
Police Chief | Shut up! Now, what ship are you from?
Captain | We are from the SS Mother Goose, we were twelve days out from Port of Spain, and I ...
| The door is flung open and the second - trouserless - guard rushes in.
Second Guard | I got thirty bob for the trousers!
Captain | We are from SS Mother Goose. We were twelve days out from Port of Spain, and one night I was doing my usual rounds, when I had occasion to pass the forward storage lockers...
| Slightly eerie music has crept in under his words and the screen goes into a ripple. It gets right out of focus and continues to ripple as it pulls back into focus. Ripple stops and they are still in the same set as they were.
Police Chief | Go on!
Captain | Well, I noticed something unusual, the main bilge hatches had been opened... (at this point three men in brown coats come in and start taking pictures off the wall, clearing props and chairs from the set, etc.) and there, crouching amidst the scuppers was the most ghastly creature I'd ever seen in my life. (the flats start to be flown up, revealing behind a sitting room - so that we can see the police office has been built in the Kelly's sitting room) As soon as it saw me, its horrible face split aside in a ghastly look of terror. His head, which was like ...
Scene Shifter | Could you sign this please? (handing the captain a piece of paper) Thank you.
Captain | A small, small rat was ghastly and horrible and befurred... its little red eyes glinted in the unaccustomed glare of the midday sun and before I could shut the hatch, it sprang upon me with one almighty...
| By this time the whole office set has been removed revealing the Kelly's boarding house sitting room. Mr and Mrs Kelly come in through door and put their heads round.
Mrs Kelly | What's this about doing the 'Horse of the Year Show' in here tonight?
Police Chief | I'm sorry, Mrs Kelly. We don't know, I'm afraid - this is drama.
Mrs Kelly | Mr Fox told me, before he went down to the pub, that they were doing 'Horse of the Year Show' in here tonight at 9.10.
Police Chief | This is BBC 2.
Captain | I think BBC 1 are in the kitchen.
Mrs Kelly | Well, I'm not having Harvey Smith jumping over my binette.
Mr Kelly | No, come on. (they go)
Captain | ... tearing at my throat, ripping my clothes...
| Mr Kelly puts his head round the door.
Mr Kelly | And turn the gas off before you leave!
Police Chief | All right!!
| Mr Kelly goes.
Captain | I fought it with all my strength, but it was too much for me...
| Cut to Mr and Mrs Kelly coming through the hall. We can hear the captain's voice growing faster. Mr and Mrs Kelly go towards the kitchen door and stop and listen. We have lost the captain's voice by now, but from inside the kitchen we hear 'Horse of the Year Show' sound track.
Dorian Williams | (voice over) Another clear round for Harvey Smith on 'Orealley'.
Commentator | (voice over on tannoy) And now it's Mrs David Barker riding 'Atalanta' Number 3.
| Crash of breaking pottery, falling pots and pans, horse neighing.
Mrs Kelly | Right! That's it! (they throw door open and march into the kitchen; a horse plus Pat Hornsby Smith and the commentator and the wreckage of a jump) Come on now, out! All of you - get out of my kitchen, all of you - come on! Harvey Smith, get out of here!
| She chases them out and down the hall.
Paul Fox | (emerging from another door) It's one of our most popular programmes.
Mrs Kelly | That's what you think, Mr Fox!
| She shooshes them all out down the passage and out of the front door. The newsreader with a blanket over him joins them and tries to read off a piece of paper.
Newsreader | Well, that's all from BBC Television for this evening...
Mrs Kelly | (slamming door on him) Shove off! Go and find yourself another flat! Get out!
| As she slams the door, a piece of paper (obviously a tax return form) is shoved through the door. It has the credits scribbled hurriedly on it; the camera pans into it. After the credits Mrs Kelly stamps on the paper. Fade out. Showbix music, cut to a sign saying 'It's'. Pull out to reveal glossy, spangly, opulent showbiz set. Two extraordinarily famous guests sitting on sofas.
Announcer's Voice | Tonight from London your special guests are Lulu, Ringo Starr and the man you've all been waiting for - your host for tonight...
| More music. The 'It's' man, tattered and ragged as usual, emerges onto set.
Lulu | Love the outfit dear, it's gorgeous...
It's Man | Hello, good evening, welcome. It's...
| The signature tune and opening animated titles start. The 'It's' man, still visible through the titles, tries in vain to stop them. The guests walk off in disgust. The 'It's' man tries to drag them back. Failing, he sits down as the music ends. Fade out.